aboutsummaryrefslogtreecommitdiffstats
path: root/libempathy-gtk/empathy-contact-widget.c
diff options
context:
space:
mode:
authorXavier Claessens <xclaesse@gmail.com>2007-10-13 19:47:48 +0800
committerXavier Claessens <xclaesse@src.gnome.org>2007-10-13 19:47:48 +0800
commit0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad (patch)
treee3b4078a2ee06cd777a50399771a2fca7263898d /libempathy-gtk/empathy-contact-widget.c
parentb4b1a54e84d210404ebc0f6c3e80622bc277ebc0 (diff)
downloadgsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.tar
gsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.tar.gz
gsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.tar.bz2
gsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.tar.lz
gsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.tar.xz
gsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.tar.zst
gsoc2013-empathy-0ab84cc3ffe6129ae40ad436eb62fccbd52b00ad.zip
Use g_timeout_add_seconds when appropriated to avoid weaking the process
2007-10-13 Xavier Claessens <xclaesse@gmail.com> * libempathy-gtk/empathy-main-window.c: * libempathy-gtk/empathy-presence-chooser.c: * libempathy-gtk/empathy-contact-list-view.c: * libempathy-gtk/empathy-contact-widget.c: * libempathy-gtk/empathy-chat.c: * libempathy-gtk/empathy-contact-list-store.c: * libempathy-gtk/empathy-chat-window.c: * libempathy/empathy-idle.c: * tests/contact-manager.c: Use g_timeout_add_seconds when appropriated to avoid weaking the process too much. svn path=/trunk/; revision=370
Diffstat (limited to 'libempathy-gtk/empathy-contact-widget.c')
-rw-r--r--libempathy-gtk/empathy-contact-widget.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libempathy-gtk/empathy-contact-widget.c b/libempathy-gtk/empathy-contact-widget.c
index afd434f3f..34a8023fe 100644
--- a/libempathy-gtk/empathy-contact-widget.c
+++ b/libempathy-gtk/empathy-contact-widget.c
@@ -42,8 +42,8 @@
#include "empathy-avatar-image.h"
#include "empathy-ui-utils.h"
/* Delay before updating the widget when the id entry changed (ms) */
#define ID_CHANGED_TIMEOUT 500
typedef struct {
EmpathyContactFactory *factory;
@@ -329,9 +329,9 @@ contact_widget_id_changed_cb (GtkEntry *entry,
}
self->widget_id_timeout =
- g_timeout_add (ID_CHANGED_TIMEOUT,
- (GSourceFunc) contact_widget_id_activate_timeout,
- self);
+ g_timeout_add_seconds (ID_CHANGED_TIMEOUT,
+ (GSourceFunc) contact_widget_id_activate_timeout,
+ self);
}
static void
@@ -42,8 +42,8 @@
#include "empathy-avatar-image.h"
#include "empathy-ui-utils.h"
-/* Delay before updating the widget when the id entry changed (ms) */
-#define ID_CHANGED_TIMEOUT 500
+/* Delay before updating the widget when the id entry changed (seconds) */
+#define ID_CHANGED_TIMEOUT 1
typedef struct {
EmpathyContactFactory *factory;